# Data for testing rate transient analysis

The Society of Petroleum Engineers (SPE) provides data for academic purposes. To
download this data, go to the
[SPE Data Repository](https://www.spe.org/en/industry/data-repository/) website.
Production data is in the RTA dataset, along with information about the
reservoir properties and well trajectories.

Examples using this data are provided in the docs.

For illustration purposes, we include SPE Data Repository: Data Set: 1, Well
Number: 20. From URL:
<https://www.spe.org/datasets/dataset_1/csv_files/dataset_1_well_20/>
